@@ -3,6 +3,8 @@ from __future__ import absolute_import
 import tempfile
 import xapian
 
+from . tools import geoprint
+
 from . database import (
     Database,
     JSONDatabase,
@@ -17,6 +19,7 @@ from . elements import (
     Dict,
     Integer,
     List,
+    Location,
     NumericRange,
     Schema,
     String,
@@ -30,12 +33,16 @@ __all__ = [
     'DateTime',
     'Dict',
     'Integer',
+    'JSONDatabase',
+    'LanguageDecider',
     'List',
+    'Location',
     'MultipleValueRangeProcessor',
     'NumericRange',
     'Schema',
     'String',
     'Text',
+    'geoprint',
     'inmemory',
     'open',
     'temp',
