@@ -345,6 +345,7 @@ class Database(object):
         try:
             # hit the property to refresh this value
             count = self.value_count
+            count = count # pyflakes
         except ValueError:
             if self._writable:
                 self.value_count = 0
@@ -394,6 +395,17 @@ class Database(object):
 
     def querify(self, query, language=None, translit='translit/long',
                 default_op=Query.OP_AND, parser_flags=default_parser_flags):
+        """Return a query object, constructed from a string, query
+        object, or mixed sequence of any number of strings, query
+        objects, or subsequences of the same form.
+
+        If 'query' is a xapian query object, it is returned unchanged.
+        If it's a string, it is parsed with xapian's query parser and
+        returned.  If it is a sequence, a new query is constructed
+        with the 'default_op' operator and the sequence is iterated
+        into the new query, recursively querify on each item of the
+        sequence.
+        """
         if isinstance(query, Query):
             return query
         if isinstance(query, basestring):
