@@ -1,4 +1,3 @@
-import datetime
 import xapian
 import unicodedata
 import translitcodec
@@ -6,6 +5,8 @@ import translitcodec
 from flatland import schema
 
 from . import snowball
+from . tools import geoprint
+
 from .exc import (
     InvalidTermError,
     )
@@ -97,6 +98,8 @@ class Schema(schema.Form):
                     h = self._handle_string
                 elif isinstance(el, Integer):
                     h = self._handle_integer
+                elif isinstance(el, Float):
+                    h = self._handle_float
                 elif isinstance(el, Boolean):
                     h = self._handle_boolean
                 elif isinstance(el, Date):
@@ -107,6 +110,8 @@ class Schema(schema.Form):
                     h = self._handle_text
                 elif isinstance(el, NumericRange):
                     h = self._handle_numericrange
+                elif isinstance(el, Location):
+                    h = self._handle_location
                 elif isinstance(el, List):
                     h = self._handle_children
                 elif isinstance(el, Dict):
@@ -145,6 +150,10 @@ class Schema(schema.Form):
         if value:
             self._handle_scalar(value, value, element, 'integer', True)
 
+    def _handle_float(self, element):
+        # TODO:mp floats are currently storage only
+        pass
+
     def _handle_boolean(self, element):
         value = 'true' if element.value else 'false'
         if value:
@@ -216,6 +225,12 @@ class Schema(schema.Form):
         if element.facet:
             self._add_term(element.name, self.facet_prefix, True)
 
+    def _handle_location(self, element):
+        h = 'loc_' + element.hash(element.radians)
+        self._add_term(h, boolean=True)
+        if element.facet:
+            self._add_term(element.name, self.facet_prefix, True)
+
     def _check_prefix(self, name, boolean=False):
         database = self.database
         prefixes = database.relevance_prefixes.copy()
@@ -345,6 +360,11 @@ class Integer(schema.Integer, _BaseElement):
     pass
 
 
+# TODO:mp, float are currently storage only
+class Float(schema.Float, _BaseElement):
+    pass
+
+
 class Date(schema.Date, _BaseElement):
 
     term_format = '%Y%m%d'
@@ -448,3 +468,36 @@ class NumericRange(_BaseRange):
     step = 1
     """The step size for the numeric range.  Default is 1.
     """
+
+
+class Location(schema.Compound, _BaseElement):
+    """ Compound location is a 2-tuple of lat/lon coordinates.
+    """
+
+    radians = False
+    """Presume elements coordinates are in radians.
+    """
+    
+    child_cls = Float
+    
+    def __compound_init__(cls):
+        cls.field_schema = [
+            cls.child_cls.using(name='lat',
+                                optional=cls.optional),
+            cls.child_cls.using(name='lon',
+                                optional=cls.optional),
+            ]
+
+    def compose(self):
+        numbers = (self['lat'].value, self['lon'].value)
+        display = ' by '.join(str(n) for n in numbers)
+        return display, numbers
+
+    def explode(self, value):
+        self['lat'] = value[0]
+        self['lon'] = value[1]
+
+    def hash(self, radians=False):
+        lat = self['lat'].value
+        lon = self['lon'].value
+        return geoprint.encode(lat, lon, radians=radians)
